summaryrefslogtreecommitdiffstats
path: root/src/kvirc/kvs
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:06:29 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:06:29 -0600
commit2dd6d32bd821b303aa7b25edda76d1ef7c14b2bf (patch)
tree9cf20f45e85e8192ae89b22807cf1e82e5012cd9 /src/kvirc/kvs
parentf91149819be7e7f45e68f22876f3c0062a11d4b9 (diff)
downloadkvirc-2dd6d32bd821b303aa7b25edda76d1ef7c14b2bf.tar.gz
kvirc-2dd6d32bd821b303aa7b25edda76d1ef7c14b2bf.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'src/kvirc/kvs')
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp20
-rw-r--r--src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp16
-rw-r--r--src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser.cpp22
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_command.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_comment.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_dollar.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_expression.cpp4
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_lside.cpp10
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_macros.h8
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp24
-rw-r--r--src/kvirc/kvs/kvi_kvs_processmanager.cpp2
-rw-r--r--src/kvirc/kvs/kvi_kvs_report.cpp16
-rw-r--r--src/kvirc/kvs/kvi_kvs_switchlist.h2
-rw-r--r--src/kvirc/kvs/kvi_kvs_treenode_operation.cpp10
-rw-r--r--src/kvirc/kvs/kvi_kvs_variant.cpp40
19 files changed, 96 insertions, 96 deletions
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
index 0610328..f376b58 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions.cpp
@@ -47,7 +47,7 @@ namespace KviKvsCoreFunctions
// a_f
_REGFNC("active",active)
_REGFNC("array",array)
- _REGFNC("ascii",tqunicode)
+ _REGFNC("ascii",unicode)
_REGFNC("asciiToHex",asciiToHex)
_REGFNC("asciiToBase64",asciiToBase64)
_REGFNC("away",away)
@@ -121,7 +121,7 @@ namespace KviKvsCoreFunctions
_REGFNC("true",trueCKEYWORDWORKAROUND)
_REGFNC("typeof",typeofCKEYWORDWORKAROUND)
_REGFNC("u",u)
- _REGFNC("tqunicode",tqunicode)
+ _REGFNC("unicode",unicode)
_REGFNC("unixtime",unixtime)
_REGFNC("unserialize",unserialize)
_REGFNC("username",username)
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions.h b/src/kvirc/kvs/kvi_kvs_corefunctions.h
index 31a73b7..b902ebe 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions.h
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions.h
@@ -131,7 +131,7 @@ namespace KviKvsCoreFunctions
KVSCF(trueCKEYWORDWORKAROUND);
KVSCF(typeofCKEYWORDWORKAROUND);
KVSCF(u);
- KVSCF(tqunicode);
+ KVSCF(unicode);
KVSCF(unixtime);
KVSCF(unserialize);
KVSCF(username);
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
index 60fbe44..096ff3c 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions_af.cpp
@@ -108,7 +108,7 @@ namespace KviKvsCoreFunctions
@syntax:
<variant> $ascii(<char:string>)
@description:
- This function has been renamed to $tqunicode and is present
+ This function has been renamed to $unicode and is present
only for backward compatibility.
@seealso:
[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
@@ -489,24 +489,24 @@ namespace KviKvsCoreFunctions
@title:
$char
@short:
- Returns a character specified by tqunicode
+ Returns a character specified by unicode
@syntax:
- <string> $char(<tqunicode_value:integer>)
+ <string> $char(<unicode_value:integer>)
@description:
- Returns a character corresponding to the UNICODE code <tqunicode_value>.[br]
+ Returns a character corresponding to the UNICODE code <unicode_value>.[br]
This function can not return NUL character (UNICODE 0). Basically
you should never need it: if you do, drop me a mail.[br]
- If the <tqunicode_code> is not a valid UNICODE code (or is 0), this function returns
+ If the <unicode_code> is not a valid UNICODE code (or is 0), this function returns
an empty string.[br]
@seealso:
- [fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$tqunicode[/fnc]
+ [fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$unicode[/fnc]
*/
KVSCF(charCKEYWORDWORKAROUND)
{
kvs_uint_t ac;
KVSCF_PARAMETERS_BEGIN
- KVSCF_PARAMETER("tqunicode_value",KVS_PT_UINT,0,ac)
+ KVSCF_PARAMETER("unicode_value",KVS_PT_UINT,0,ac)
KVSCF_PARAMETERS_END
if(ac != 0 && ac < 65536)
@@ -780,15 +780,15 @@ namespace KviKvsCoreFunctions
const TQChar * c = KviTQString::nullTerminatedArray(szFormat);
if(c)
{
- while(c->tqunicode())
+ while(c->unicode())
{
//Check for right Characters
#ifdef COMPILE_ON_WINDOWS
- if (szAllowedCharacters.find((char)(c->tqunicode()),0,true) >= 0) tmpFormat += '%';
+ if (szAllowedCharacters.find((char)(c->unicode()),0,true) >= 0) tmpFormat += '%';
#else
if (c->isLetter()) tmpFormat += '%';
#endif
- tmpFormat += (char)(c->tqunicode());
+ tmpFormat += (char)(c->unicode());
c++;
}
}
diff --git a/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp b/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
index a5478dc..e56abbe 100644
--- a/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
+++ b/src/kvirc/kvs/kvi_kvs_corefunctions_sz.cpp
@@ -401,12 +401,12 @@ namespace KviKvsCoreFunctions
if(szLongSwitch.isEmpty())
v = sl->find(szSwitch);
else
- v = sl->find(szSwitch[0].tqunicode(),szLongSwitch);
+ v = sl->find(szSwitch[0].unicode(),szLongSwitch);
}else {
if(szLongSwitch.isEmpty())
v = sl->find(szSwitch[0]);
else
- v = sl->find(szSwitch[0].tqunicode(),szLongSwitch);
+ v = sl->find(szSwitch[0].unicode(),szLongSwitch);
}
if(v)KVSCF_pRetBuffer->copyFrom(*v);
@@ -842,15 +842,15 @@ namespace KviKvsCoreFunctions
/////////////////////////////////////////////////////////////////////////////////////////
/*
- @doc: tqunicode
+ @doc: unicode
@type:
function
@title:
- $tqunicode
+ $unicode
@short:
Returns the UNICODE code of a sets of characters
@syntax:
- <variant> $tqunicode(<char:string>)
+ <variant> $unicode(<char:string>)
@description:
If <char> is composed only of a single character
then returns its UNICODE code point as an integer.
@@ -860,7 +860,7 @@ namespace KviKvsCoreFunctions
[fnc]$cr[/fnc], [fnc]$lf[/fnc], [fnc]$char[/fnc]
*/
- KVSCF(tqunicode)
+ KVSCF(unicode)
{
TQString sz;
KVSCF_PARAMETERS_BEGIN
@@ -871,10 +871,10 @@ namespace KviKvsCoreFunctions
{
KviKvsArray * a = new KviKvsArray();
for(kvs_int_t i=0;i<sz.length();i++)
- a->set(i,new KviKvsVariant((kvs_int_t)(sz[(int)i].tqunicode())));
+ a->set(i,new KviKvsVariant((kvs_int_t)(sz[(int)i].unicode())));
KVSCF_pRetBuffer->setArray(a);
} else {
- KVSCF_pRetBuffer->setInteger((kvs_int_t)(sz[0].tqunicode()));
+ KVSCF_pRetBuffer->setInteger((kvs_int_t)(sz[0].unicode()));
}
return true;
}
diff --git a/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp b/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
index acf8eec..85c6c5c 100644
--- a/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
+++ b/src/kvirc/kvs/kvi_kvs_coresimplecommands_sz.cpp
@@ -673,7 +673,7 @@ namespace KviKvsCoreSimpleCommands
to load catalogues that reside in different directories.[br]
[b]NOTE[/b][br]
This feature is currently work in progress: the scripting engine
- is not yet fully tqunicode and thus some more exotic translations may still suffer...
+ is not yet fully unicode and thus some more exotic translations may still suffer...
@seealso:
[fnc]$tr[/fnc], [cmd]trunload[/cmd]
*/
diff --git a/src/kvirc/kvs/kvi_kvs_parser.cpp b/src/kvirc/kvs/kvi_kvs_parser.cpp
index fc483f5..074753e 100644
--- a/src/kvirc/kvs/kvi_kvs_parser.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser.cpp
@@ -117,9 +117,9 @@ void KviKvsParser::report(bool bError,const TQChar * pLocation,const TQString &s
void KviKvsParser::errorBadChar(const TQChar * pLocation,char cExpected,const char * szCommandName)
{
- if(pLocation->tqunicode())
- error(pLocation,__tr2qs("Found character '%q' (tqunicode 0x%x) where '%c' was expected: see \"/help %s\" for the command syntax"),
- pLocation,pLocation->tqunicode(),cExpected,szCommandName);
+ if(pLocation->unicode())
+ error(pLocation,__tr2qs("Found character '%q' (unicode 0x%x) where '%c' was expected: see \"/help %s\" for the command syntax"),
+ pLocation,pLocation->unicode(),cExpected,szCommandName);
else
error(pLocation,__tr2qs("Found end of input where character '%c' was expected: see \"/help %s\" for the command syntax"),
cExpected,szCommandName);
@@ -1349,7 +1349,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
so the callback code is empty, but if you continue reading we will soon fill it.
[/p]
- [big]A typical addon tqlayout[/big]
+ [big]A typical addon layout[/big]
[p]
As stated above, the addons are usually shipped in a compressed archive.
Once uncompressed, the archive will expand into a small directory tree
@@ -1400,7 +1400,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
[/p]
[p]
The entries in [b]bold[/b] are directories while the other are files.
- Please note that this is a general tqlayout for a huge and rather complex
+ Please note that this is a general layout for a huge and rather complex
addon: you might not need all of these directories. Remember: the minimal
addon has only an install.kvs file. Anyway, a really cool addon
will probably have all of them and maybe some more.
@@ -1496,7 +1496,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseAsParameter(const TQChar * pBuffe
[p]
It is a good idea to start on the KVIrc web site. There are surely
several addons to look at. Pick one that seems simple and analyze its
- tqlayout and code (wow... the free software!). It will be easier to do than it was to explain it :D
+ layout and code (wow... the free software!). It will be easier to do than it was to explain it :D
[/p]
[p]
Have fun! :)
@@ -2724,7 +2724,7 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseInstruction()
return parseCommand();
} else {
// what the heck is this ?
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where an instruction was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where an instruction was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
break;
@@ -2839,7 +2839,7 @@ KviKvsTreeNodeSwitchList * KviKvsParser::parseCommandSwitchList()
if(KVSP_curCharUnicode == 0)
{
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a switch dash"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a switch dash"),KVSP_curCharPointer,KVSP_curCharUnicode);
} else {
error(KVSP_curCharPointer,__tr2qs("Unexpected end of script after a switch dash"));
}
@@ -2880,12 +2880,12 @@ KviKvsTreeNodeSwitchList * KviKvsParser::parseCommandSwitchList()
if(bLong)
sw->addLong(TQString(pSw,pSwEnd - pSw),p);
else
- sw->addShort(pSw->lower().tqunicode(),p);
+ sw->addShort(pSw->lower().unicode(),p);
} else {
if(bLong)
sw->addLong(TQString(pSw,pSwEnd - pSw),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
else
- sw->addShort(pSw->lower().tqunicode(),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
+ sw->addShort(pSw->lower().unicode(),new KviKvsTreeNodeConstantData(KVSP_curCharPointer,new KviKvsVariant(true))); // empty param
}
}
@@ -3300,7 +3300,7 @@ KviKvsTreeNodeData * KviKvsParser::parseArrayIndex()
error(KVSP_curCharPointer,__tr2qs("Unexpected end of line in array index (missing ']' character or unescaped newline)"));
break;
default:
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) in array index: it should be already terminated"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) in array index: it should be already terminated"),KVSP_curCharPointer,KVSP_curCharUnicode);
break;
}
return 0;
diff --git a/src/kvirc/kvs/kvi_kvs_parser_command.cpp b/src/kvirc/kvs/kvi_kvs_parser_command.cpp
index 094fc30..865bf18 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_command.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_command.cpp
@@ -139,7 +139,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseCommand()
// perl.begin has a *really* half special parsing routine
if(iIdentifierLen == 4)
{
- if(pIdentifier->lower().tqunicode() == 'p')
+ if(pIdentifier->lower().unicode() == 'p')
{
if(KviTQString::equalCI(szIdentifier,"perl"))
{
diff --git a/src/kvirc/kvs/kvi_kvs_parser_comment.cpp b/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
index 18fbbbe..ea15840 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_comment.cpp
@@ -85,7 +85,7 @@ KviKvsTreeNode * KviKvsParser::parseComment()
}
break;
default:
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a slash (it is a typo or a malformed comment begin ?)"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a slash (it is a typo or a malformed comment begin ?)"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
break;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp b/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
index a2d6516..b556614 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_dollar.cpp
@@ -50,7 +50,7 @@ KviKvsTreeNodeData * KviKvsParser::parseDollar(bool bInObjScope)
if(!KVSP_curCharIsFunctionStart)
{
if(KVSP_curCharUnicode == 0)warning(KVSP_curCharPointer,__tr2qs("Unexpected end of script after '$' function call prefix"));
- else warning(KVSP_curCharPointer,__tr2qs("Unexpected character %q (tqunicode %x) after '$' function call prefix"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ else warning(KVSP_curCharPointer,__tr2qs("Unexpected character %q (unicode %x) after '$' function call prefix"),KVSP_curCharPointer,KVSP_curCharUnicode);
error(KVSP_curCharPointer,__tr2qs("Syntax error after '$' function call prefix. If you want to use a plain '$' in the code you need to escape it"));
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_expression.cpp b/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
index ee91df4..44ce71d 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_expression.cpp
@@ -420,7 +420,7 @@ KviKvsTreeNodeExpression * KviKvsParser::parseExpressionOperandCore(char termina
pDataList->append(new KviKvsTreeNodeConstantData(pBegin,new KviKvsVariant(iVal)));
} else {
// bOk is false
- if(pBegin->tqunicode() == '0')
+ if(pBegin->unicode() == '0')
{
if(tmp.length() > 2)
{
@@ -448,7 +448,7 @@ KviKvsTreeNodeExpression * KviKvsParser::parseExpressionOperandCore(char termina
}
}
} else {
- error(KVSP_curCharPointer,__tr2qs("Unexpected character %q (tqunicode %h) in expression. If it meant to be a string use the quotes."),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character %q (unicode %h) in expression. If it meant to be a string use the quotes."),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pDataList;
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_parser_lside.cpp b/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
index 3733f55..bcca75d 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_lside.cpp
@@ -828,7 +828,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -846,7 +846,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pFirst;
return 0;
}
@@ -869,7 +869,7 @@ KviKvsTreeNodeOperation * KviKvsParser::parseBindingOperation()
if(KVSP_curCharUnicode != '/')
{
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where a slash '/' was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pFirst;
return 0;
}
@@ -1173,10 +1173,10 @@ KviKvsTreeNodeInstruction * KviKvsParser::parseVoidFunctionCallOrOperation()
// must be followed by the end of a command
if(r->isFunctionCall())
{
- error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (tqunicode %x) after a void function call: end of instruction expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Unexpected character '%q' (unicode %x) after a void function call: end of instruction expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
} else {
warning(pBegin,__tr2qs("Unexpected (and senseless) read-only data evaluation"));
- warning(pBegin,__tr2qs("Unexpected character '%q' (tqunicode %x)"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ warning(pBegin,__tr2qs("Unexpected character '%q' (unicode %x)"),KVSP_curCharPointer,KVSP_curCharUnicode);
error(KVSP_curCharPointer,__tr2qs("Syntax error: confused by earlier errors: bailing out"));
}
delete r;
diff --git a/src/kvirc/kvs/kvi_kvs_parser_macros.h b/src/kvirc/kvs/kvi_kvs_parser_macros.h
index e727e4a..8de1f47 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_macros.h
+++ b/src/kvirc/kvs/kvi_kvs_parser_macros.h
@@ -29,15 +29,15 @@
#define KVSP_backChar m_ptr--
#define KVSP_backNChars(n) m_ptr -= n
-#define KVSP_curCharUnicode (m_ptr->tqunicode())
+#define KVSP_curCharUnicode (m_ptr->unicode())
#define KVSP_curCharPointer m_ptr
#define KVSP_curCharIsLetter (m_ptr->isLetter())
#define KVSP_curCharIsNumber (m_ptr->isNumber())
#define KVSP_curCharIsLetterOrNumber (m_ptr->isLetterOrNumber())
-#define KVSP_curCharIsFunctionStart (m_ptr->isLetterOrNumber() || (m_ptr->tqunicode() == '(') || (m_ptr->tqunicode() == '{') || (m_ptr->tqunicode() == '$'))
-#define KVSP_curCharIsEndOfCommand ((m_ptr->tqunicode() == ';') || (m_ptr->tqunicode() == 0) || (m_ptr->tqunicode() == '\n') || (m_ptr->tqunicode() == '\r'))
-#define KVSP_curCharIsEndOfBuffer (m_ptr->tqunicode() == 0)
+#define KVSP_curCharIsFunctionStart (m_ptr->isLetterOrNumber() || (m_ptr->unicode() == '(') || (m_ptr->unicode() == '{') || (m_ptr->unicode() == '$'))
+#define KVSP_curCharIsEndOfCommand ((m_ptr->unicode() == ';') || (m_ptr->unicode() == 0) || (m_ptr->unicode() == '\n') || (m_ptr->unicode() == '\r'))
+#define KVSP_curCharIsEndOfBuffer (m_ptr->unicode() == 0)
#define KVSP_setCurCharPointer(_ptr) m_ptr = _ptr
diff --git a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
index 95eca6a..6d6ab96 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
@@ -207,7 +207,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandUnset()
if(!KVSP_curCharIsEndOfCommand)
{
warning(KVSP_curCharPointer,__tr2qs("The 'unset' command needs a variable list"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -277,7 +277,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandGlobal()
if(!KVSP_curCharIsEndOfCommand)
{
warning(KVSP_curCharPointer,__tr2qs("The 'global' command needs a variable list"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a variable was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -376,7 +376,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharUnicode != '(')
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -443,7 +443,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -471,7 +471,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -498,7 +498,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a function name was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pClass;
return 0;
}
@@ -628,7 +628,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandWhile()
if(KVSP_curCharUnicode != '(')
{
warning(KVSP_curCharPointer,__tr2qs("The while command needs an expression enclosed in parenthesis"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -740,7 +740,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandDo()
if(KVSP_curCharIsEndOfBuffer)
error(KVSP_curCharPointer,__tr2qs("Unexpected end of command after the 'do' command block: expected 'while' keyword"));
else
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'while' keyword was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'while' keyword was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
if(i)delete i;
return 0;
}
@@ -1089,7 +1089,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandFor()
if(KVSP_curCharUnicode != ')')
{
- error(KVSP_curCharPointer,__tr2qs("Found char %q (tqunicode %x) while looking for the terminating ')' in 'for' command"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found char %q (unicode %x) while looking for the terminating ')' in 'for' command"),KVSP_curCharPointer,KVSP_curCharUnicode);
if(i1)delete i1;
if(e)delete e;
if(i2)delete i2;
@@ -1193,7 +1193,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandForeach()
if((KVSP_curCharUnicode != '%') && (KVSP_curCharUnicode != '$') && (KVSP_curCharUnicode != '@'))
{
warning(KVSP_curCharPointer,__tr2qs("The 'foreach' command expects a writeable iteration variable as first parameter"));
- error(KVSP_curCharPointer,__tr2qs("Found character '%q' (tqunicode %x) where '%' or '$' was expected: see /help foreach for the command syntax"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character '%q' (unicode %x) where '%' or '$' was expected: see /help foreach for the command syntax"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -1419,7 +1419,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandSwitch()
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'case','match','regexp','default' or 'break' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'case','match','regexp','default' or 'break' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pSwitch;
return 0;
}
@@ -1566,7 +1566,7 @@ KviKvsTreeNodeSpecialCommandDefpopupLabelPopup * KviKvsParser::parseSpecialComma
if(KVSP_curCharPointer == pLabelBegin)
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where a 'prologue','separator','label','popup','item','extpopup' or 'epilogue' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (unicode %x) where a 'prologue','separator','label','popup','item','extpopup' or 'epilogue' label was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
delete pPopup;
return 0;
}
diff --git a/src/kvirc/kvs/kvi_kvs_processmanager.cpp b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
index 53ac882..c80794e 100644
--- a/src/kvirc/kvs/kvi_kvs_processmanager.cpp
+++ b/src/kvirc/kvs/kvi_kvs_processmanager.cpp
@@ -73,7 +73,7 @@ bool KviKvsProcessAsyncOperation::start()
if(szShell.isEmpty())
{
#ifdef COMPILE_ON_WINDOWS
- // [01:26:00] <PragmaOff> btw, what is qt_wintqunicode ?
+ // [01:26:00] <PragmaOff> btw, what is qt_winunicode ?
// [01:26:12] <kode54> TQt export specific to win32
// [01:26:27] <kode54> bool which indicates whether system is Unicode (NT) or not
// [01:26:58] <kode54> not sure if that's documented, but it is a public export
diff --git a/src/kvirc/kvs/kvi_kvs_report.cpp b/src/kvirc/kvs/kvi_kvs_report.cpp
index aa40ef3..7618e29 100644
--- a/src/kvirc/kvs/kvi_kvs_report.cpp
+++ b/src/kvirc/kvs/kvi_kvs_report.cpp
@@ -60,7 +60,7 @@ void KviKvsReport::findLineAndCol(const TQChar * pBegin,const TQChar * pPoint,in
const TQChar * pPrevLine = 0;
const TQChar * pLineBegin = pBegin;
- unsigned short us = pBegin->tqunicode();
+ unsigned short us = pBegin->unicode();
while(us && (pBegin < pPoint))
{
@@ -73,7 +73,7 @@ void KviKvsReport::findLineAndCol(const TQChar * pBegin,const TQChar * pPoint,in
} else {
pBegin++;
}
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
}
iCol = (pBegin - pLineBegin) + 1;
@@ -92,7 +92,7 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
const TQChar * pPrevLine = 0;
const TQChar * pLineBegin = pBegin;
- unsigned short us = pBegin->tqunicode();
+ unsigned short us = pBegin->unicode();
while(us && (pBegin < pPoint))
{
@@ -105,7 +105,7 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
} else {
pBegin++;
}
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
}
iCol = (pBegin - pLineBegin) + 1;
@@ -131,11 +131,11 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
// current line
pBegin = pLineBegin;
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
while(us && (us != '\n'))
{
pBegin++;
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
}
if(us)pBegin++;
@@ -152,11 +152,11 @@ void KviKvsReport::findLineColAndListing(const TQChar * pBegin,const TQChar * pP
// next line
pLineBegin = pBegin;
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
while(us && (us != '\n'))
{
pBegin++;
- us = pBegin->tqunicode();
+ us = pBegin->unicode();
}
if(us)pBegin++;
diff --git a/src/kvirc/kvs/kvi_kvs_switchlist.h b/src/kvirc/kvs/kvi_kvs_switchlist.h
index b82d93f..fc31461 100644
--- a/src/kvirc/kvs/kvi_kvs_switchlist.h
+++ b/src/kvirc/kvs/kvi_kvs_switchlist.h
@@ -48,7 +48,7 @@ public:
KviKvsVariant * find(const TQChar &c)
{
- return m_pShortSwitchDict ? m_pShortSwitchDict->find(c.tqunicode()) : 0;
+ return m_pShortSwitchDict ? m_pShortSwitchDict->find(c.unicode()) : 0;
};
KviKvsVariant * find(unsigned short uShortKey)
diff --git a/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp b/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
index 26b05b9..bdb1310 100644
--- a/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
+++ b/src/kvirc/kvs/kvi_kvs_treenode_operation.cpp
@@ -1467,18 +1467,18 @@ bool KviKvsTreeNodeOperationStringSubstitution::execute(KviKvsRunTimeContext * c
TQString szReplaced;
const TQChar * p2 = KviTQString::nullTerminatedArray(szR);
const TQChar * begin = p2;
- while(p2->tqunicode())
+ while(p2->unicode())
{
- if(p2->tqunicode() == '\\')
+ if(p2->unicode() == '\\')
{
p2++;
- if(p2->tqunicode() >= '0' && p2->tqunicode() <= '9')
+ if(p2->unicode() >= '0' && p2->unicode() <= '9')
{
szReplaced.append(TQString(begin,(p2 - begin) - 1));
- szReplaced.append(re.cap(p2->tqunicode() - '0'));
+ szReplaced.append(re.cap(p2->unicode() - '0'));
p2++;
begin = p2;
- } else if(p2->tqunicode())p2++;
+ } else if(p2->unicode())p2++;
} else p2++;
}
if(begin != p2)szReplaced.append(TQString(begin,p2 - begin));
diff --git a/src/kvirc/kvs/kvi_kvs_variant.cpp b/src/kvirc/kvs/kvi_kvs_variant.cpp
index c4e457f..b2da370 100644
--- a/src/kvirc/kvs/kvi_kvs_variant.cpp
+++ b/src/kvirc/kvs/kvi_kvs_variant.cpp
@@ -1010,7 +1010,7 @@ KviKvsVariant* KviKvsVariant::unserializeNull(const TQChar** aux)
KviKvsVariant* KviKvsVariant::unserializeRealOrInteger(const TQChar** aux)
{
TQString data;
- if((*aux)->tqunicode() == '-')
+ if((*aux)->unicode() == '-')
{
data.append('-');
(*aux)++;
@@ -1024,7 +1024,7 @@ KviKvsVariant* KviKvsVariant::unserializeRealOrInteger(const TQChar** aux)
data.append(**aux);
(*aux)++;
}
- if((*aux)->tqunicode()=='.')
+ if((*aux)->unicode()=='.')
{
return unserializeReal(aux,data);
}
@@ -1042,15 +1042,15 @@ KviKvsVariant* KviKvsVariant::unserializeReal(const TQChar** aux,TQString& data)
(*aux)++;
}
- if((*aux)->tqunicode() == 'e' || (*aux)->tqunicode() == 'E')
+ if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
{
(*aux)++;
- if((*aux)->tqunicode() == '-')
+ if((*aux)->unicode() == '-')
{
exponent.append('-');
(*aux)++;
} else {
- if((*aux)->tqunicode() == '+')
+ if((*aux)->unicode() == '+')
{
exponent.append('+');
(*aux)++;
@@ -1079,15 +1079,15 @@ KviKvsVariant* KviKvsVariant::unserializeInteger(const TQChar** aux,TQString& da
TQString exponent;
- if((*aux)->tqunicode() == 'e' || (*aux)->tqunicode() == 'E')
+ if((*aux)->unicode() == 'e' || (*aux)->unicode() == 'E')
{
(*aux)++;
- if((*aux)->tqunicode() == '-')
+ if((*aux)->unicode() == '-')
{
exponent.append('-');
(*aux)++;
} else {
- if((*aux)->tqunicode() == '+')
+ if((*aux)->unicode() == '+')
{
exponent.append('+');
(*aux)++;
@@ -1122,9 +1122,9 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
TQString hex; //temp var
//skip leading "
(*aux)++;
- while((*aux)->tqunicode())
+ while((*aux)->unicode())
{
- switch((*aux)->tqunicode())
+ switch((*aux)->unicode())
{
case '"':
//EOF
@@ -1134,7 +1134,7 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
case '\\':
//Special
(*aux)++;
- switch((*aux)->tqunicode())
+ switch((*aux)->unicode())
{
case 't':
data.append('\t');
@@ -1159,11 +1159,11 @@ void KviKvsVariant::unserializeString(const TQChar** aux,TQString& data)
//4 hexadecmical digits pending...
hex="";
(*aux)++;
- for(int k=0;k<4 && (*aux)->tqunicode(); k++)
+ for(int k=0;k<4 && (*aux)->unicode(); k++)
{
if((*aux)->isDigit() ||
- ((*aux)->tqunicode() >='A' && (*aux)->tqunicode() <='F')|| //ABCDEF
- ((*aux)->tqunicode() >='a' && (*aux)->tqunicode() <='f')) //abcdef
+ ((*aux)->unicode() >='A' && (*aux)->unicode() <='F')|| //ABCDEF
+ ((*aux)->unicode() >='a' && (*aux)->unicode() <='f')) //abcdef
{
hex.append(**aux);
(*aux)++;
@@ -1203,7 +1203,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
//waiting for starting of string
- if((*aux)->tqunicode()!='\"')
+ if((*aux)->unicode()!='\"')
{
//strange characters
delete pHash;
@@ -1221,7 +1221,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
//waiting for name-value delimeter
- if((*aux)->tqunicode()!=':')
+ if((*aux)->unicode()!=':')
{
//strange characters
delete pHash;
@@ -1238,7 +1238,7 @@ KviKvsVariant* KviKvsVariant::unserializeHash(const TQChar** aux)
i++;
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->tqunicode())
+ switch((*aux)->unicode())
{
case ',':
//goto next
@@ -1278,7 +1278,7 @@ KviKvsVariant* KviKvsVariant::unserializeArray(const TQChar** aux)
i++;
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->tqunicode())
+ switch((*aux)->unicode())
{
case ',':
//goto next
@@ -1310,7 +1310,7 @@ KviKvsVariant* KviKvsVariant::unserialize(const TQChar** aux)
while((*aux)->isSpace())
(*aux)++;
- switch((*aux)->tqunicode())
+ switch((*aux)->unicode())
{
case 't':
//true
@@ -1373,7 +1373,7 @@ KviKvsVariant* KviKvsVariant::unserialize(const TQString& data)
pResult = unserialize(&aux);
- if(aux->tqunicode())
+ if(aux->unicode())
{
//strange extra characters?
if(pResult) delete pResult;
diff --git a/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp b/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
index 0a4aa54..4f11db0 100644
--- a/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
+++ b/src/kvirc/kvs/kvi_kvs_coresimplecommands_af.cpp
@@ -427,7 +427,7 @@ namespace KviKvsCoreSimpleCommands
// TQChar o = tbOp.length() > 0 ? tbOp[0] : TQChar('x');
- switch(o.tqunicode())
+ switch(o.unicode())
{
case 't':
KviTalToolTip::remove(pButton);
@@ -853,7 +853,7 @@ namespace KviKvsCoreSimpleCommands
{
TQString szWnd;
v->asString(szWnd);
//#warning "FIXME: the window database is not tqunicode! (we even could keep integer window id's at this point!)"
pWnd = g_pApp->findWindow(szWnd.utf8().data());
if(!pWnd)
{
@@ -853,7 +853,7 @@ namespace KviKvsCoreSimpleCommands
TQString szWnd;
v->asString(szWnd);
- //#warning "FIXME: the window database is not tqunicode! (we even could keep integer window id's at this point!)"
+ //#warning "FIXME: the window database is not unicode! (we even could keep integer window id's at this point!)"
pWnd = g_pApp->findWindow(szWnd.utf8().data());
if(!pWnd)